==> YNQ-1.5.0_Linux_S_CP.zip: YNQ-1.5.0_Linux_S_CP/NQ Library Reference/html/group__amapi.js <==
var group__amapi =
[
    [ "Encryption Algorithms", "group__enc__alg.html", "group__enc__alg" ],
    [ "Security Mechanisms", "group__sec__mech.html", "group__sec__mech" ],
    [ "Security Password Type", "group__pass__type.html", "group__pass__type" ],
    [ "AMDomainA", "structAMDomainA.html", [
      [ "name", "structAMDomainA.html#ab09355f64e0b7bc5ee4311527f7cd23b", null ],
      [ "realm", "structAMDomainA.html#a3f9543fb64dc0fc12f933eafa4d8ad75", null ]
    ] ],
    [ "AMDomain", "structAMDomain.html", [
      [ "name", "structAMDomain.html#a1e5a363609a0d37d90888e606158a2f1", null ],
      [ "realm", "structAMDomain.html#a3211f7b9fc3dd81fce758c65cf5a4584", null ]
    ] ],
    [ "AMCredentialsA", "structAMCredentialsA.html", [
      [ "domain", "structAMCredentialsA.html#a0513425a6c69fd1471bd16e933abfd5e", null ],
      [ "user", "structAMCredentialsA.html#a21490b59aad8db67b349ae0f7d36c174", null ],
      [ "password", "structAMCredentialsA.html#a75f1481308d65f824d14212efc2ec345", null ],
      [ "type", "structAMCredentialsA.html#afd947838507484515d7e9ca66a400f9c", null ]
    ] ],
    [ "AMCredentials", "structAMCredentials.html", [
      [ "domain", "structAMCredentials.html#acc2ee1f3d9a31f36e030107f15ae2e54", null ],
      [ "user", "structAMCredentials.html#a767cb0d97a2190b694ac0bb82e7e02d3", null ],
      [ "password", "structAMCredentials.html#a9b9f94f1673210fe202dcf3b1681a139", null ],
      [ "type", "structAMCredentials.html#a7fca99685a57ba6327f2546d92d38f53", null ]
    ] ],
    [ "AM_MAXSECURITYLEVEL", "group__amapi.html#ga1782c89eb28f17f23dab3139628f8878", null ],
    [ "amStart", "group__amapi.html#gad0cce72dea4a7d6e8118854a13f39f0d", null ],
    [ "amShutdown", "group__amapi.html#ga36672b1def2c4f67788c7b4f5784d353", null ],
    [ "amClientDefineLevel", "group__amapi.html#gad38eb05c6fe26e8e380a51043f69e9a0", null ],
    [ "amSetNonSecureAuthentication", "group__amapi.html#ga148de2e5fef47dd9093c7393c291f36e", null ]
];

==> YNQ-1.6.2_Linux_S_CP.zip: YNQ-1.6.2_Linux_S_CP/NQ Library Reference/html/group__amapi.js <==
var group__amapi =
[
    [ "Encryption Algorithms", "group__enc__alg.html", "group__enc__alg" ],
    [ "Security Mechanisms", "group__sec__mech.html", "group__sec__mech" ],
    [ "Security Password Type", "group__pass__type.html", "group__pass__type" ],
    [ "AMDomainA", "structAMDomainA.html", [
      [ "name", "structAMDomainA.html#ab09355f64e0b7bc5ee4311527f7cd23b", null ],
      [ "realm", "structAMDomainA.html#a3f9543fb64dc0fc12f933eafa4d8ad75", null ]
    ] ],
    [ "AMDomain", "structAMDomain.html", [
      [ "name", "structAMDomain.html#a1e5a363609a0d37d90888e606158a2f1", null ],
      [ "realm", "structAMDomain.html#a3211f7b9fc3dd81fce758c65cf5a4584", null ]
    ] ],
    [ "AMCredentialsA", "structAMCredentialsA.html", [
      [ "domain", "structAMCredentialsA.html#a0513425a6c69fd1471bd16e933abfd5e", null ],
      [ "user", "structAMCredentialsA.html#a21490b59aad8db67b349ae0f7d36c174", null ],
      [ "password", "structAMCredentialsA.html#a75f1481308d65f824d14212efc2ec345", null ],
      [ "type", "structAMCredentialsA.html#afd947838507484515d7e9ca66a400f9c", null ]
    ] ],
    [ "AMCredentials", "structAMCredentials.html", [
      [ "domain", "structAMCredentials.html#acc2ee1f3d9a31f36e030107f15ae2e54", null ],
      [ "user", "structAMCredentials.html#a767cb0d97a2190b694ac0bb82e7e02d3", null ],
      [ "password", "structAMCredentials.html#a9b9f94f1673210fe202dcf3b1681a139", null ],
      [ "type", "structAMCredentials.html#a7fca99685a57ba6327f2546d92d38f53", null ]
    ] ],
    [ "AM_MAXSECURITYLEVEL", "group__amapi.html#ga1782c89eb28f17f23dab3139628f8878", null ],
    [ "amStart", "group__amapi.html#gad0cce72dea4a7d6e8118854a13f39f0d", null ],
    [ "amShutdown", "group__amapi.html#ga36672b1def2c4f67788c7b4f5784d353", null ],
    [ "amClientDefineLevel", "group__amapi.html#gad38eb05c6fe26e8e380a51043f69e9a0", null ],
    [ "amSetNonSecureAuthentication", "group__amapi.html#ga148de2e5fef47dd9093c7393c291f36e", null ],
    [ "amCredentialsAsciiiToW", "group__amapi.html#ga741605e967d0f86cc362bd8abde9856e", null ],
    [ "amCredentialsInit", "group__amapi.html#ga516fbaf46ba8b4ee3bb2d79a06c7966e", null ],
    [ "amCredentialsInitA", "group__amapi.html#ga9e12294f645430bbf85b90da60a6e6de", null ]
];
